@@ -17,11 +17,10 @@ class Adder2d(ex.Adder2d):
                  input_channel,
                  output_channel,
                  kernel_size,
+                 bias=False,
                  stride=1,
                  padding=0,
-                 bias=False,
                  weight_bit_width=8,
-                 bias_bit_width=16,
                  inter_bit_width=32,
                  acti_bit_width=8,
                  retrain=True,
@@ -29,11 +28,10 @@ class Adder2d(ex.Adder2d):
         super().__init__(input_channel,
                          output_channel,
                          kernel_size,
+                         bias=bias,
                          stride=stride,
-                         padding=padding,
-                         bias=bias)
+                         padding=padding)
         self.weight_bit_width = weight_bit_width
-        self.bias_bit_width = bias_bit_width
         self.inter_bit_width = inter_bit_width
         self.acti_bit_width = acti_bit_width
         self.retrain = retrain
@@ -41,18 +39,12 @@ class Adder2d(ex.Adder2d):
         if retrain is True:
             self.weight_log2_t = nn.Parameter(torch.Tensor(1))
             self.acti_log2_t = nn.Parameter(torch.Tensor(1))
-            if self.bias is not None:
-                self.bias_log2_t = nn.Parameter(torch.Tensor(1))
         else:
             self.weight_log2_t = torch.Tensor(1)
             self.acti_log2_t = torch.Tensor(1)
-            if self.bias is not None:
-                self.bias_log2_t = torch.Tensor(1)
 
     def static(self):
         self.retrain = False
-        if isinstance(self.bias_log2_t, nn.Parameter):
-            self.bias_log2_t.requires_grad_(False)
         if isinstance(self.weight_log2_t, nn.Parameter):
             self.weight_log2_t.requires_grad_(False)
         if isinstance(self.acti_log2_t, nn.Parameter):
@@ -65,28 +57,19 @@ class Adder2d(ex.Adder2d):
         self.quant = False
 
     def adder_forward(self, input):
-        input_log2_t = input.abs().max().log2()
         weight = qsigned(self.weight, self.weight_log2_t,
                          self.weight_bit_width)
-        inter = qsigned(
-            ex.adder2d_function(input,
-                                weight,
-                                None,
-                                stride=self.stride,
-                                padding=self.padding),
-            self.weight_log2_t + input_log2_t + math.log2(self.weight.numel()),
-            self.inter_bit_width)
 
-        if self.bias is not None:
-            inter += qsigned(
-                self.bias, self.bias_log2_t,
-                self.bias_bit_width).unsqueeze(1).unsqueeze(2).unsqueeze(0)
-        return qsigned(inter, self.acti_log2_t, self.acti_bit_width)
+        out = ex.adder2d_function(input,
+                                  weight,
+                                  stride=self.stride,
+                                  padding=self.padding)
+
+        return out
 
     def adder_forward_unquant(self, input):
         return ex.adder2d_function(input,
                                    self.weight,
-                                   self.bias,
                                    stride=self.stride,
                                    padding=self.padding)
 
